TextItem class

Constructors

TextItem({required Text text, double space = 10, double startAngle = 0, StartAngleAlignment startAngleAlignment = StartAngleAlignment.start, CircularTextDirection direction = CircularTextDirection.clockwise})

Properties

direction → CircularTextDirection
Text direction either clockwise or anticlockwise
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space → double
Space between characters
final
startAngle → double
Text starting position
final
startAngleAlignment → StartAngleAlignment
Text alignment around startAngle StartAngleAlignment.start text will starts from startAngle StartAngleAlignment.center text will be centered on startAngle StartAngleAlignment.end text will ends on startAngle
final
text → Text
Text
final

Methods

isChanged(TextItem oldTextItem) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited